@@ -76,12 +76,12 @@ set vars(library_sets)        "libs_typical"
 
 set vars(libs_typical,timing) [join "
                                 $vars(adk_dir)/stdcells.lib
-                                [glob -nocomplain $vars(adk_dir)/stdcells-lvt.lib]
-                                [glob -nocomplain $vars(adk_dir)/stdcells-ulvt.lib]
-                                [glob -nocomplain $vars(adk_dir)/stdcells-pm.lib]
-                                [glob -nocomplain $vars(adk_dir)/iocells.lib]
-                                [glob -nocomplain inputs/*tt*.lib]
-                                [glob -nocomplain inputs/*TT*.lib]
+                                [lsort [glob -nocomplain $vars(adk_dir)/stdcells-lvt.lib]]
+                                [lsort [glob -nocomplain $vars(adk_dir)/stdcells-ulvt.lib]]
+                                [lsort [glob -nocomplain $vars(adk_dir)/stdcells-pm.lib]]
+                                [lsort [glob -nocomplain $vars(adk_dir)/iocells.lib]]
+                                [lsort [glob -nocomplain inputs/*tt*.lib]]
+                                [lsort [glob -nocomplain inputs/*TT*.lib]]
                               "]
 
 # The best case is:
@@ -93,13 +93,13 @@ set vars(libs_typical,timing) [join "
 if {[file exists $vars(adk_dir)/stdcells-bc.lib]} {
   set vars(libs_bc,timing)    [join "
                                 $vars(adk_dir)/stdcells-bc.lib
-                                [glob -nocomplain $vars(adk_dir)/stdcells-lvt-bc.lib]
-                                [glob -nocomplain $vars(adk_dir)/stdcells-ulvt-bc.lib]
-                                [glob -nocomplain $vars(adk_dir)/stdcells-pm-bc.lib]
-                                [glob -nocomplain $vars(adk_dir)/iocells-bc.lib]
-                                [glob -nocomplain $vars(adk_dir)/*-bc*.lib]
-                                [glob -nocomplain inputs/*ff*.lib]
-                                [glob -nocomplain inputs/*FF*.lib]
+                                [lsort [glob -nocomplain $vars(adk_dir)/stdcells-lvt-bc.lib]]
+                                [lsort [glob -nocomplain $vars(adk_dir)/stdcells-ulvt-bc.lib]]
+                                [lsort [glob -nocomplain $vars(adk_dir)/stdcells-pm-bc.lib]]
+                                [lsort [glob -nocomplain $vars(adk_dir)/iocells-bc.lib]]
+                                [lsort [glob -nocomplain $vars(adk_dir)/*-bc*.lib]]
+                                [lsort [glob -nocomplain inputs/*ff*.lib]]
+                                [lsort [glob -nocomplain inputs/*FF*.lib]]
                               "]
   lappend vars(library_sets)  "libs_bc"
 }
@@ -113,9 +113,12 @@ if {[file exists $vars(adk_dir)/stdcells-bc.lib]} {
 if {[file exists $vars(adk_dir)/stdcells-wc.lib]} {
   set vars(libs_wc,timing)    [join "
                                 $vars(adk_dir)/stdcells-wc.lib
-                                [glob -nocomplain $vars(adk_dir)/iocells-wc.lib]
-                                [glob -nocomplain inputs/*ss*.lib]
-                                [glob -nocomplain inputs/*SS*.lib]
+                                [lsort [glob -nocomplain $vars(adk_dir)/stdcells-lvt-wc.lib]]
+                                [lsort [glob -nocomplain $vars(adk_dir)/stdcells-ulvt-wc.lib]]
+                                [lsort [glob -nocomplain $vars(adk_dir)/stdcells-pm-wc.lib]]
+                                [lsort [glob -nocomplain $vars(adk_dir)/iocells-wc.lib]]
+                                [lsort [glob -nocomplain inputs/*ss*.lib]]
+                                [lsort [glob -nocomplain inputs/*SS*.lib]]
                               "]
   lappend vars(library_sets)  "libs_wc"
 }
@@ -123,9 +126,9 @@ if {[file exists $vars(adk_dir)/stdcells-wc.lib]} {
 set vars(lef_files) [join "
                       $vars(adk_dir)/rtk-tech.lef
                       $vars(adk_dir)/stdcells.lef
-                      [glob -nocomplain $vars(adk_dir)/stdcells-pm.lef]
-                      [glob -nocomplain $vars(adk_dir)/*.lef]
-                      [glob -nocomplain inputs/*.lef]
+                      [lsort [glob -nocomplain $vars(adk_dir)/stdcells-pm.lef]]
+                      [lsort [glob -nocomplain $vars(adk_dir)/*.lef]]
+                      [lsort [glob -nocomplain inputs/*.lef]]
                     "]
 
 #-------------------------------------------------------------------------
@@ -196,12 +199,24 @@ set vars(delay_default,early_library_set)    libs_typical
 set vars(delay_default,late_library_set)     libs_typical
 set vars(delay_default,rc_corner)            typical
 
+if {[lsearch -exact $vars(rc_corners) "rcbest"] != -1} {
+  lappend vars(delay_corners) "delay_best"
+  set vars(delay_best,early_library_set)    libs_typical
+  set vars(delay_best,late_library_set)     libs_typical
+  set vars(delay_best,rc_corner)            rcbest
+}
+
 # Use the best case for hold instead if the files are available
 
 if {[file exists $vars(adk_dir)/stdcells-bc.lib]} {
   set vars(delay_default,early_library_set)    libs_bc
+  if {[lsearch -exact $vars(delay_corners) "delay_best"] != -1} {
+    set vars(delay_best,early_library_set)    libs_bc
+  }
 }
 
+
+
 #-------------------------------------------------------------------------
 # Delay Corners (old bc_wc style)
 #-------------------------------------------------------------------------
@@ -238,6 +253,12 @@ set vars(analysis_views)                       "analysis_default"
 set vars(analysis_default,delay_corner)        delay_default
 set vars(analysis_default,constraint_mode)     constraints_default
 
+if {[lsearch -exact $vars(delay_corners) "delay_best"] != -1} {
+  lappend vars(analysis_views)                   "analysis_hold"
+  set vars(analysis_hold,delay_corner)           delay_best
+  set vars(analysis_hold,constraint_mode)        constraints_default
+}
+
 # Analysis views for setup and hold
 #
 # Notes:
@@ -270,6 +291,12 @@ set vars(default_hold_view)                    "analysis_default"
 set vars(hold_analysis_views)                  "analysis_default"
 set vars(active_hold_views)                    "analysis_default"
 
+if {[lsearch -exact $vars(analysis_views) "analysis_hold"] != -1} {
+  set vars(default_hold_view)                    "analysis_hold"
+  set vars(hold_analysis_views)                  "analysis_hold"
+  set vars(active_hold_views)                    "analysis_hold"
+}
+
 # Misc
 
 set vars(power_analysis_view)                  analysis_default
@@ -374,6 +401,10 @@ set vars(route,restore_design,skip)             true
 set vars(postroute,restore_design,skip)         true
 set vars(signoff,restore_design,skip)           true
 
+# Replace "routeDesign" command with contents of "route-design-check.tcl"
+
+set vars(route,route_design,replace_tcl)      $vars(custom_scripts_dir)/route-design-check.tcl
+
 # Custom GDS stream out tcl
 
 set vars(gds_layer_map)                       $vars(adk_dir)/rtk-stream-out.map
