@@ -89,6 +89,8 @@ ln -sf ../results/*.mapped.v       design.v
 ln -sf ../results/*.mapped.sdc     design.sdc
 ln -sf ../results/*.mapped.spef.gz design.spef.gz
 ln -sf ../reports/*.namemap        design.namemap
+ln -sf ../results/*.svf            design.svf
+ln -sf ../results/*.upf            design.upf
 
 cd ..
 
