@@ -31,6 +31,11 @@ if {[file exists [which setup-design-params.txt]]} {
 current_design $dc_design_name
 link
 
+# Load UPF if it exists
+if {[file exists $dc_upf]} {
+  load_upf $dc_upf
+}
+
 #-------------------------------------------------------------------------
 # Write out useful files
 #-------------------------------------------------------------------------
